capture log close
clear all
macro drop _all
version 16.1
cd "/Volumes/Mike2019/MC_CLIENTS/2021/ACCC Electricity Benchmarking/Stata"
set more off
log using crDNSPbench-state3, replace text
set scheme vg_s1c

/*--------------------------------------------------------------------------
Project: Economic Insights DNSP Benchmarking
Author:  Michael Cunningham
File:    crDNSPbench-state3.do
Initial Date:    15-July-2021
Revised Date:	 25-Sep-2021
--------------------------------------------------------------------------*/

local varlist revenue energy ratchetmd customers circlength cmos ///
	price_cmos opex price_opex overheadst overheadd undergrst undergrd ///
    transform auc_overheadst auc_overheadd auc_undergrst auc_undergrd  ///
	auc_transform maxdemand mdindex 	

import excel using DNSPbench_v3.xlsx, sheet("Shazam State Data") firstrow ///
	cellrange(A1:W91) case(l) clear
	
gen int state = 0
replace state = 1 if state_name == "ACT"
replace state = 2 if state_name == "NSW" 
replace state = 3 if state_name == "VIC"
replace state = 4 if state_name == "QLD"
replace state = 5 if state_name == "SA"
replace state = 6 if state_name == "TAS"
labmask state, val(state_name)
drop state_name

describe

sort state year
xtset state year	
	
label variable state 		"State or Territory"
label variable year 		"Year (Financial or calendar is applicable)"
label variable revenue   	"Total Revenue ($'000)"
label variable energy    	"Energy (GWh)"	
label variable customers 	"Customer Numbers (No.)"	
label variable maxdemand 	"Maximum Demand (MW)"
label variable ratchetmd   	"Ratched Maximum Demand	(MW)"
label variable circlength   "Circuit Length	(kms)"
label variable cmos   		"Customer Minutes Off Supply (mins)"	
label variable price_cmos   "Price: Customer Minutes Off Supply ($/min)"	
label variable opex   		"Opex ($'000)"
label variable price_opex   "Price: Opex (Index 2006 = 1)"
label variable overheadst	"Overhead Subtransmission Lines (33kV and over) (MVAkms)"
label variable overheadd    "Overhead Distribution Lines (under 33kV) (MVAkms)"
label variable undergrst    "Underground Subtransmission Lines (33kV and over) (MVAkms)"
label variable undergrd     "Underground Distribution Lines (under 33kV) (MVAkms)"	
label variable transform    "Transformers Excluding First Stage of Two Stage (MVA)"	
label variable auc_overheadst "AUC Overhead Subtransmission ($'000)"	
label variable auc_overheadd "AUC Overhead Distribution ($'000)"	
label variable auc_undergrst "AUC Underground Subtransmission ($'000)"	
label variable auc_undergrd  "AUC Underground Distribution ($'000)"	
label variable auc_transform "AUC Transformers Excluding First Stage of Two Stage ($'000)"	
label variable mdindex      "Maximum demand (index 2006 = 1.0)"	


gen idyear = 4000 + state*100 + year - 2000
list idyear in 1/20
list idyear in 71/90


format %14.0g `varlist'

save dnspbench-state3, replace


describe
tab1 state year
summarize `varlist'
misstable summarize `varlist'

*** Create State DNSP Shazam input data files ********

	
local datfiles DACTdata.csv DNSWdata.csv DVICdata.csv DQLDdata.csv ///
	DSAdata.csv DTASdata.csv 

local j = 1	
foreach k of local datfiles {
	outsheet year `varlist' using `k' if state == `j', comma
	local ++j
}

outsheet idyear `varlist' using STATEdata.csv, comma

log close
exit

