capture log close
clear all
macro drop _all
version 16.1
cd "/Volumes/Mike2019/MC_CLIENTS/2021/ACCC Electricity Benchmarking/Stata"
set more off
log using crDNSPopex2, replace text
set scheme vg_s1c

/*--------------------------------------------------------------------------
Project: Economic Insights DNSP Opex Cost Function
Author:  Michael Cunningham
File:    crDNSPopex2.do
Initial Date:    3-Aug-2021 (as crDNSPopex1.do)
Revised Date:	 28-Sep-2021
--------------------------------------------------------------------------*/

local varlist opex propex maxdem rmdem custnum circlen shareugc
tempfile nzdat candat


* Import data for NZ

import excel using "Economic Insights AER DNSP NZ Ont Data 3Aug2021.xlsx", ///
	sheet("DNSP NZ Med 2019ABR") cellrange(A1:K286) firstrow case(l) clear
describe

replace name = "MainPower" if name == "MainPower NZ" | name == "Mainpower"
replace name = "Unison" if name == "Unison Networks"
rename rmdemand rmdem

sort eiid year
tabulate eiid year
summarize `varlist'
misstable summarize `varlist'

save `nzdat'


* Import data for Canada

import excel using "Economic Insights AER DNSP NZ Ont Data 3Aug2021.xlsx", ///
	sheet("DNSP Ont Med 2019ABR") cellrange(A1:L531) firstrow case(l) clear
describe

replace name = "Entegrus Powerlines" if name == "Entegrus Powerlines Inc."
drop uglen
rename rmdemand rmdem

sort eiid year
tabulate eiid year
summarize `varlist'
misstable summarize `varlist'

save `candat'


* Combine Aust data with overseas utility data

use dnspbench-firm3, clear

gen country = 1
rename price_opex propex
rename maxdemand maxdem
rename ratchetmd rmdem
rename customers custnum
rename circlength circlen
rename ucshare shareugc
rename dnsp eiid

sort eiid year
keep eiid year country `varlist'
order eiid year country `varlist'
describe

append using `nzdat' `candat'
sort eiid year

gen int obs = _n
gen int dnsp = 1
forvalues i = 1/69 {
	replace dnsp = dnsp[_n-1]  if eiid == eiid[_n-1] & obs > 1
	replace dnsp = dnsp[_n-1] + 1  if eiid > eiid[_n-1]
}

labmask eiid, values(name) lblname(utilname1)
labmask dnsp, values(name) lblname(utilname2)
drop name

label define countryname 1 "Aust" 2 "NZ" 3 "Canada"
label values country countryname

label define utilname1 1 "Evoenergy" 2 "Ausgrid" 3 "CitiPower" ///
	4 "Endeavour Energy" 5 "Energex" 6 "Ergon Energy" 7 "Essential Energy" ///
	8 "Jemena" 9 "Powercor" 10 "SA Power Networks" 11 "AusNet Dist." ///
	12 "TasNetworks Dist." 13 "United Energy", modify
label define utilname2 1 "Evoenergy" 2 "Ausgrid" 3 "CitiPower" ///
	4 "Endeavour Energy" 5 "Energex" 6 "Ergon Energy" 7 "Essential Energy" ///
	8 "Jemena" 9 "Powercor" 10 "SA Power Networks" 11 "AusNet Dist." ///
	12 "TasNetworks Dist." 13 "United Energy", modify
	
describe
tabulate eiid
summarize `varlist'
misstable summarize `varlist'


save DNSPopex2, replace


log close
exit

